from base import BaseEntity
from user import User

class Opportunity(BaseEntity, User):
    def __init__(self, id, **kwargs):
        self.phone = ""
        self.country = ""
        self.state = ""

        self.set_params(kwargs)
        BaseEntity.__init__(self, id)



import json

class BaseEntity:
    def __init__(self, id):
        self.id = id

    def set_params(self, params):
        for key, value in params.items():
            try:
                setattr(self, key, value)
            except AttributeError as e:
                pass
    
    def to_dict(self):
        return self.__dict__
    
    def to_json(self):
        return json.dumps(self.to_dict())



class User:
    def __init__(self):
        self.email = ""
        self.first_name = ""
        self.last_name = ""

    @property
    def name(self):
        return F"{self.first_name} {self.last_name}"



from lib2to3.pytree import Base
from base import BaseEntity

class Call(Base):
    def __init__(self, id, **kwargs):
        account_sid = ""
        answered_by = None
        caller_name = None
        direction = ""
        duration = None
        forwarded_from = ""
        from_formatted = ""
        _from = ""
        group_sid = None
        parent_call_sid = None
        phone_number_sid = ""
        sid = ""
        start_time = ""
        status = ""
        to = ""
        to_formatted = ""
        trunk_sid = None
        queue_time = None
        
        self.set_params(kwargs)
        BaseEntity.__init__(self, id)



from base import BaseEntity
from user import User

class Agent(BaseEntity, User):
    def __init__(self, id, **kwargs):
        self.conference = None
        self.is_busy = False
        self.queue_type = None
        self.tenant = None
        
        self.set_params(kwargs)
        BaseEntity.__init__(self, id)



from base import BaseEntity

class Tenant(BaseEntity):
    def __init__(self, id, **kwargs):
        self.accountSid = ""
        self.authToken = ""
        self.domain = ""

        self.set_params(kwargs)
        BaseEntity.__init__(self, id)



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()
    
setup(
    name='wf-autodialer-entities',
    version='0.1.1',    
    description='Webforce autodialer entities',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Webforce',
    author_email='master@webforcehq.com',
    packages=['wf_autodialer_entities'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


from base import BaseEntity

class Conference(BaseEntity):
    def __init__(self, id, **kwargs):
        self.caller = ""
        self.friendly_name = ""
        self.total_participants = 0
        
        self.set_params(kwargs)
        BaseEntity.__init__(id)
